@@ -16,9 +16,9 @@
 import os
 from docutils import nodes
 from docutils.parsers import rst
-from actdiag import diagparser
+from actdiag import parser
 from actdiag.builder import ScreenNodeBuilder
-from actdiag.DiagramDraw import DiagramDraw
+from actdiag.drawer import DiagramDraw
 from blockdiag.utils.rst import directives
 
 
@@ -42,7 +42,7 @@ class ActdiagDirective(directives.BlockdiagDirective):
     node_class = actdiag
 
     def node2diagram(self, node):
-        tree = diagparser.parse_string(node['code'])
+        tree = parser.parse_string(node['code'])
         return ScreenNodeBuilder.build(tree)
 
     def node2image(self, node, diagram):
